Learn R Programming

rols (version 1.10.0)

allIds: Returns all identifiers and terms of an ontology

Description

This function returns all identifiers and terms available for given valid ontology. It sends a getAllTermsFromOntologyRequest SOAP message and retrieves and parses the getAllTermsFromOntologyResponse. The original interface is public Map getAllTermsFromOntology(String ontologyName).

Usage

allIds(ontologyName, simplify = TRUE)

Arguments

ontologyName
A character with the name of a valid ontology name.
simplify
A logical indicating whether the S4 Map instance should be simplified. Default is TRUE.

Value

A named character if simplify is TRUE. An instance of class Map otherwise.

See Also

Other ols-queries: isIdObsolete; olsQuery; olsVersion; ontologies; ontologyLoadDate; ontologyNames; rootId; termMetadata; termXrefs; term

Examples

Run this code
allIds("MS", simplify=FALSE)

Run the code above in your browser using DataLab