Learn R Programming

rols (version 1.8.0)

isIdObsolete: Is the ontology id obsolete

Description

When terms are found to be outside the scope of an ontology, are misleadingly named or defined or describe a concept that would be better represented in another way, the terms are marked obsolete rather than deleted. This function tests this by sending an isObsoleteRequest SOAP message and retrieves and parses the isObsoleteResponse. The original interface is public boolean isObsolete(String termId, String ontologyName).

Usage

isIdObsolete(termId, ontologyName)

Arguments

termId
A character with a valid ontology identifier.
ontologyName
A character with the name of a valid ontology name.

Value

A logical specifying if the term id is obsolete.

See Also

Other ols-queries: allIds; olsQuery; olsVersion; ontologies; ontologyLoadDate; ontologyNames; rootId; termMetadata; termXrefs; term

Examples

Run this code
## is obsolete
term("GO:0005563", "GO")
isIdObsolete(termId = "GO:0005563", ontologyName = "GO")
stopifnot(isIdObsolete(termId = "GO:0005563", ontologyName = "GO"))
## replaced by
term("GO:0030533", "GO")
isIdObsolete(termId = "GO:0030533", ontologyName = "GO")

Run the code above in your browser using DataLab