Learn R Programming

rols (version 1.8.0)

ontologyLoadDate: Returns the ontology load date

Description

This function returns the load date of a given ontology. The ontology name must be valid, i.e. exists in ontologies(). It sends a getOntologyLoadDateRequest SOAP message and retrieves and parses the getOntologyLoadDateResponse. The original interface is public String getOntologyLoadDate(String ontologyName).

Usage

ontologyLoadDate(ontologyName)

Arguments

ontologyName
A character with the name of a valid ontology name.

Value

A character with the ontology's load date.

See Also

Other ols-queries: allIds; isIdObsolete; olsQuery; olsVersion; ontologies; ontologyNames; rootId; termMetadata; termXrefs; term

Examples

Run this code
ontologyLoadDate("GO")
ontologyLoadDate("FIX")

Run the code above in your browser using DataLab