Learn R Programming

rols (version 1.8.0)

rols-package: R OLS interface

Description

An R interface to the Ontology Lookup Service

Arguments

Details

The Ontology Lookup Service (OLS) is a spin-off of the PRIDE project. It provides a web service interface to query multiple ontologies from a single location with a unified output format. This package allows to query the OLS from within R.

References

http://www.ebi.ac.uk/ontology-lookup/