This function returns the load date of a given
ontology. The ontology name must be valid, i.e. exists
in ontologies().
It sends a getOntologyLoadDateRequest SOAP message
and retrieves and parses the getOntologyLoadDateResponse.
The original interface is
public String getOntologyLoadDate(String ontologyName).
Usage
ontologyLoadDate(ontologyName)
Arguments
ontologyName
A character with the name of a valid ontology name.